@@ -1,10 +1,9 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011,
-    2012, 2013, 2014 Antonio Diaz Diaz.
+    Copyright (C) 2003-2014 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
+    the Free Software Foundation, either version 2 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -20,6 +19,7 @@
 #include <cstddef>
 #include <cstdio>
 #include <cstdlib>
+#include <vector>
 
 #include "common.h"
 #include "rectangle.h"
@@ -39,7 +39,7 @@ Rectangle::Rectangle( const int l, const int t, const int r, const int b )
     {
     if( verbosity >= 0 )
       std::fprintf( stderr, "l = %d, t = %d, r = %d, b = %d\n", l, t, r, b );
-    error( "bad parameter building a Rectangle" );
+    error( "bad parameter building a Rectangle." );
     }
   left_ = l; top_ = t; right_ = r; bottom_ = b;
   }
@@ -47,42 +47,42 @@ Rectangle::Rectangle( const int l, const int t, const int r, const int b )
 
 void Rectangle::left( const int l )
   {
-  if( l > right_ ) error( "left, bad parameter resizing a Rectangle" );
+  if( l > right_ ) error( "left, bad parameter resizing a Rectangle." );
   left_ = l;
   }
 
 
 void Rectangle::top( const int t )
   {
-  if( t > bottom_ ) error( "top, bad parameter resizing a Rectangle" );
+  if( t > bottom_ ) error( "top, bad parameter resizing a Rectangle." );
   top_ = t;
   }
 
 
 void Rectangle::right( const int r )
   {
-  if( r < left_ ) error( "right, bad parameter resizing a Rectangle" );
+  if( r < left_ ) error( "right, bad parameter resizing a Rectangle." );
   right_ = r;
   }
 
 
 void Rectangle::bottom( const int b )
   {
-  if( b < top_ ) error( "bottom, bad parameter resizing a Rectangle" );
+  if( b < top_ ) error( "bottom, bad parameter resizing a Rectangle." );
   bottom_ = b;
   }
 
 
 void Rectangle::height( const int h )
   {
-  if( h <= 0 ) error( "height, bad parameter resizing a Rectangle" );
+  if( h <= 0 ) error( "height, bad parameter resizing a Rectangle." );
   bottom_ = top_ + h - 1;
   }
 
 
 void Rectangle::width( const int w )
   {
-  if( w <= 0 ) error( "width, bad parameter resizing a Rectangle" );
+  if( w <= 0 ) error( "width, bad parameter resizing a Rectangle." );
   right_ = left_ + w - 1;
   }
 
@@ -277,8 +277,8 @@ int Rectangle::hypoti( const int c1, const int c2 )
   {
   long long temp = c1; temp *= temp;
   long long target = c2; target *= target; target += temp;
-  int lower = std::max( std::abs(c1), std::abs(c2) );
-  int upper = std::abs(c1) + std::abs(c2);
+  int lower = std::max( std::abs( c1 ), std::abs( c2 ) );
+  int upper = std::abs( c1 ) + std::abs( c2 );
   while( upper - lower > 1 )
     {
     int m = ( lower + upper ) / 2;
